Pearmut Listwise Evaluation

- Error spans:
  - Select the part of translation where you have identified a translation error (drag or click start & end).
  - Click on the highlight to change error severity (minor/major) or remove the highlight.
  Choose error severity:
  - Minor errors: Style, grammar, word choice could be better or more natural.
  - Major errors:: The meaning is changed significantly and/or the part is really hard to understand.
  Tip: Highlight the word or general area of the error (it doesn't need to be exact). Use separate highlights for different errors.
- Score each translation: Please use the slider and set an overall score based on meaning preservation and general quality:

- 0: No meaning preserved: most information is lost.
- 33%: Some meaning preserved: major gaps and narrative issues.
- 66%: Most meaning preserved: minor issues with grammar or consistency.
- 100%: Perfect: meaning and grammar align completely with the source.

- Error types: After highlighting an error fragment, you will be asked to select the specific error type (main category and subcategory). If you are unsure about which errors fall under which categories, please consult the typology definitions.

Time: 0m
Show approximate alignment